Index: src/x64/full-codegen-x64.cc |
=================================================================== |
--- src/x64/full-codegen-x64.cc (revision 8025) |
+++ src/x64/full-codegen-x64.cc (working copy) |
@@ -1668,7 +1668,7 @@ |
__ bind(&stub_call); |
__ movq(rax, rcx); |
- TypeRecordingBinaryOpStub stub(op, mode); |
+ BinaryOpStub stub(op, mode); |
EmitCallIC(stub.GetCode(), &patch_site, expr->id()); |
__ jmp(&done, Label::kNear); |
@@ -1715,7 +1715,7 @@ |
Token::Value op, |
OverwriteMode mode) { |
__ pop(rdx); |
- TypeRecordingBinaryOpStub stub(op, mode); |
+ BinaryOpStub stub(op, mode); |
// NULL signals no inlined smi code. |
EmitCallIC(stub.GetCode(), NULL, expr->id()); |
context()->Plug(rax); |
@@ -3723,8 +3723,8 @@ |
bool can_overwrite = expr->expression()->ResultOverwriteAllowed(); |
UnaryOverwriteMode overwrite = |
can_overwrite ? UNARY_OVERWRITE : UNARY_NO_OVERWRITE; |
- TypeRecordingUnaryOpStub stub(expr->op(), overwrite); |
- // TypeRecordingUnaryOpStub expects the argument to be in the |
+ UnaryOpStub stub(expr->op(), overwrite); |
+ // UnaryOpStub expects the argument to be in the |
// accumulator register rax. |
VisitForAccumulatorValue(expr->expression()); |
SetSourcePosition(expr->position()); |
@@ -3852,7 +3852,7 @@ |
SetSourcePosition(expr->position()); |
// Call stub for +1/-1. |
- TypeRecordingBinaryOpStub stub(expr->binary_op(), NO_OVERWRITE); |
+ BinaryOpStub stub(expr->binary_op(), NO_OVERWRITE); |
if (expr->op() == Token::INC) { |
__ Move(rdx, Smi::FromInt(1)); |
} else { |